==> ejc-proequipmentcorp-impl-3.0.0-20221228.101101-280-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/impl/OutRentSignatureServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.contract.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;

import com.ejianc.business.contractbase.filing.enums.FilingStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.enums.SignatureStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractChangeService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentSignatureService;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractVO;
import com.ejianc.foundation.file.api.IAttachmentApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service("outRentSignatureService")
public class OutRentSignatureServiceImpl implements IOutRentSignatureService {
    @Autowired
    private IOutRentContractService contractService;

    @Autowired
    private IOutRentContractChangeService changeService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IAttachmentApi attachmentApi;

//    @Value("${rentContract.mainContract}")
//    private String mainContarct;
//
//    @Value("${rentContract.changeContract}")
//    private String changeContract;


    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     * 若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     * 否则改变变更合同签章状态，修改主合同的变更合同签章状态
     *
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, int signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->{}", refCode);
        OutRentContractEntity contractEntity = contractService.selectById(id);
        if (contractEntity != null) {
            if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                contractEntity.setSignatureState(SignatureStatusEnum.已签章.getCode());
                contractEntity.setContractPerformanceState(PerformanceStatusEnum.履约中.getCode());
                contractEntity.setFilingStatus(FilingStatusEnum.已归档.getTypeCode());
                contractEntity.setFilingRef(0);
                contractEntity.setEffectiveDate(new Date());
                // 推送合同池
//                contractService.pushContract(BeanMapper.map(contractEntity, OutRentContractVO.class));
            } else {
                contractEntity.setSignatureState(String.valueOf(signatureStatus));
            }
            contractService.saveOrUpdate(contractEntity, false);

            logger.info("主合同签章状态已修改---------------->");
        } else {
            return CommonResponse.error("找不到合同，请检查合同主键！");
        }

        return CommonResponse.success("签章状态修改成功！");
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/impl/OutRentSignatureServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.contract.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;

import com.ejianc.business.contractbase.filing.enums.FilingStatusEnum;
import com.ejianc.business.proequipmentcorpout.constants.OutRentConstants;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.enums.SignatureStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractChangeService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentSignatureService;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractVO;
import com.ejianc.foundation.file.api.IAttachmentApi;
import com.ejianc.foundation.support.api.IParamConfigApi;
import com.ejianc.foundation.support.vo.ParamRegisterSetVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Date;

@Service("outRentSignatureService")
public class OutRentSignatureServiceImpl implements IOutRentSignatureService {
    @Autowired
    private IOutRentContractService contractService;

    @Autowired
    private IOutRentContractChangeService changeService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IAttachmentApi attachmentApi;

    @Autowired
    private IParamConfigApi paramConfigApi;
    private static final String UPDATE_CON_SIGN_DATE_PARAM_NAME = "P-U9uddl0182";

//    @Value("${rentContract.mainContract}")
//    private String mainContarct;
//
//    @Value("${rentContract.changeContract}")
//    private String changeContract;


    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     * 若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     * 否则改变变更合同签章状态，修改主合同的变更合同签章状态
     *
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, int signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->{}", refCode);
        OutRentContractEntity contractEntity = contractService.selectById(id);
        if (contractEntity != null) {
            if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                contractEntity.setSignatureState(SignatureStatusEnum.已签章.getCode());
                contractEntity.setContractPerformanceState(PerformanceStatusEnum.履约中.getCode());
                contractEntity.setFilingStatus(FilingStatusEnum.已归档.getTypeCode());
                contractEntity.setFilingRef(0);
                contractEntity.setEffectiveDate(new Date());

                CommonResponse<ParamRegisterSetVO> response = paramConfigApi.getByCode(UPDATE_CON_SIGN_DATE_PARAM_NAME);
                if(!response.isSuccess()) {
                    logger.error("查询电中签章合同-【id-{}】是否更新合同签订日期参数失败，暂不更新合同签订日期: {}", id, JSONObject.toJSONString(response));
                }
                if(null != response.getData() && "1".equals(response.getData().getValueData())) {
                    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                    //更新合同签订日期
                    logger.info("合同【id-{}，原签订日期：{}, 根据电子签章合同更新合同签订日期参数:{}，将合同签订日期改为当前签章完成日期:{}】",id, sdf.format(contractEntity.getSignedDate()), JSONObject.toJSONString(response.getData()), sdf.format(new Date()));
                    contractEntity.setSignedDate(new Date());
                }
                contractService.pushContractToRent(JSONObject.toJSONString(contractEntity),
                        OutRentConstants.PUSH_RENT_OPT_TYPE_ADD, OutRentConstants.PUSH_RENT_OPT_BILL_CONTRACT);
            } else {
                contractEntity.setSignatureState(String.valueOf(signatureStatus));
            }
            contractService.saveOrUpdate(contractEntity, false);
            //推送合同池
            contractService.pushContract(BeanMapper.map(contractEntity, OutRentContractVO.class));
            logger.info("主合同签章状态已修改---------------->");
        } else {
            return CommonResponse.error("找不到合同，请检查合同主键！");
        }

        return CommonResponse.success("签章状态修改成功！");
    }
}
